[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - doapfiend.utils.NotFoundError: DOAP not found
  - doapfiend.cli.DoapFiend: `DoapFiend` class
  - doapfiend.plugins.text.DoapPrinter: Prints DOAP in human readable text
  - pygments.lexer.Lexer: Lexer for a specific language.
    - pygments.lexer.RegexLexer: Base for simple stateful regular expression-based lexers.
      - doapfiend.lexers.Notation3Lexer: Lexer for the N3 / Turtle / NT
      - doapfiend.lexers.SparqlLexer: Lexer for SPARQL Not Complete
  - doapfiend.plugins.base.Plugin: Base class for doapfiend plugins.
    - doapfiend.plugins.freshmeat.FreshmeatPlugin: Get DOAP from Freshmeat package index
    - doapfiend.plugins.ohloh.OhlohPlugin: Get DOAP from Ohloh package index
    - doapfiend.plugins.text.OutputPlugin: Class for formatting DOAP output
    - doapfiend.plugins.n3.OutputPlugin: Class for formatting DOAP output
    - doapfiend.plugins.xml.OutputPlugin: Class for formatting DOAP output
    - doapfiend.plugins.fields.OutputPlugin: Class for formatting DOAP output
    - doapfiend.plugins.homepage.OutputPlugin: Class for formatting DOAP output
    - doapfiend.plugins.pypi.PyPIPlugin: Get DOAP from PyPI package index
    - doapfiend.plugins.sourceforge.SourceForgePlugin: Get DOAP from SourceForge package index
    - doapfiend.plugins.url.UrlPlugin: Class for formatting DOAP output
  - doapfiend.doaplib.rdfSubject
    - doapfiend.model.CVSRepository: CVS repository class
    - doapfiend.model.Project: DOAP Project Class
    - doapfiend.model.Release: A release class
    - doapfiend.model.SVNRepository: Subversion repository classs
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - pygments.lexer.LexerMeta: This metaclass automagically converts ``analyse_text`` methods into static methods which always return float values.
      - pygments.lexer.RegexLexerMeta: Metaclass for RegexLexer, creates the self._tokens attribute from self.tokens on the first instantiation.